@@ -153,6 +153,11 @@ class JAAQLController(BaseJAAQLController):
         def handle_webhook(application: str, name: str, body: bytes, headers: dict, args: dict, response: JAAQLResponse):
             self.model.handle_webhook(application, name, body, headers, args, response)
 
+        @self.publish_route('/secure/<application>/<name>', DOCUMENTATION__secure_webhook)
+        def handle_secure_webhook(application: str, name: str, body: bytes, headers: dict, args: dict,
+                                  response: JAAQLResponse, account_id: str):
+            self.model.handle_webhook(application, name, body, headers, args, response, account_id)
+
         @self.publish_route('/remote_procedure', DOCUMENTATION__remote_procedures)
         def handle_remote_procedure(http_inputs: dict, is_the_anonymous_user: bool, auth_token: str, username: str, ip_address: str, account_id: str):
             return self.model.handle_procedure(http_inputs, is_the_anonymous_user, auth_token, username, ip_address, account_id)
